(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common'), require('filepond')) :
    typeof define === 'function' && define.amd ? define('ngx-filepond', ['exports', '@angular/core', '@angular/common', 'filepond'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['ngx-filepond'] = {}, global.ng.core, global.ng.common, global.filepond));
}(this, (function (exports, core, common, filepond) { 'use strict';

    // We test if filepond is supported on the current client
    var isSupported = filepond.supported();
    // List of attributes for fallback input
    var inputAttributes = [
        "id",
        "name",
        "class",
        "multiple",
        "required",
        "disabled",
        "capture",
        "accept",
    ];
    // Methods not made available on the component
    var filteredComponentMethods = [
        "setOptions",
        "on",
        "off",
        "onOnce",
        "appendTo",
        "insertAfter",
        "insertBefore",
        "isAttachedTo",
        "replaceElement",
        "restoreElement",
        "destroy",
    ];
    var outputs = [
        "oninit",
        "onwarning",
        "onerror",
        "onactivatefile",
        "onaddfilestart",
        "onaddfileprogress",
        "onaddfile",
        "onprocessfilestart",
        "onprocessfileprogress",
        "onprocessfileabort",
        "onprocessfilerevert",
        "onprocessfile",
        "onprocessfiles",
        "onremovefile",
        "onpreparefile",
        "onupdatefiles",
    ];
    // Component outline
    var FilePondComponent = /** @class */ (function () {
        function FilePondComponent(root, zone) {
            this.options = {};
            // same as outputs array
            this.oninit = new core.EventEmitter();
            this.onwarning = new core.EventEmitter();
            this.onerror = new core.EventEmitter();
            this.onactivatefile = new core.EventEmitter();
            this.onaddfilestart = new core.EventEmitter();
            this.onaddfileprogress = new core.EventEmitter();
            this.onaddfile = new core.EventEmitter();
            this.onprocessfilestart = new core.EventEmitter();
            this.onprocessfileprogress = new core.EventEmitter();
            this.onprocessfileabort = new core.EventEmitter();
            this.onprocessfilerevert = new core.EventEmitter();
            this.onprocessfile = new core.EventEmitter();
            this.onprocessfiles = new core.EventEmitter();
            this.onremovefile = new core.EventEmitter();
            this.onpreparefile = new core.EventEmitter();
            this.onupdatefiles = new core.EventEmitter();
            this.handleEvent = null;
            this.root = root;
            this.zone = zone;
        }
        FilePondComponent.prototype.ngAfterViewInit = function () {
            var _this = this;
            var input = this.root.nativeElement.querySelector("input");
            // transfer relevant attributes to input, this so we still have an input with the correct attributes should file pond not load
            var attributes = this.root.nativeElement.attributes;
            inputAttributes.forEach(function (name) {
                var value = attributes[name]
                    ? attributes[name].value
                    : _this.options[name];
                if (!value) {
                    return;
                }
                input.setAttribute(name, value);
            });
            // no sufficient features supported in this browser
            if (!isSupported) {
                return;
            }
            // map FilePond events to Angular @outputs
            this.handleEvent = function (e) {
                _this["on" + e.type.split(":")[1]].emit(Object.assign({}, e.detail));
            };
            outputs.forEach(function (event) {
                _this.root.nativeElement.addEventListener("FilePond:" + event.substr(2), _this.handleEvent);
            });
            // will block angular from listening to events inside the pond
            this.zone.runOutsideAngular(function () {
                // create instance
                _this.pond = filepond.create(input, Object.assign(Object.assign({}, _this.options), {
                    // our initial files
                    files: _this.files
                }));
            });
            // Copy instance method references to component instance
            Object.keys(this.pond)
                // remove unwanted methods
                .filter(function (key) { return filteredComponentMethods.indexOf(key) === -1; })
                // set method references from the component instance to the pond instance
                .forEach(function (key) {
                _this[key] = _this.pond[key];
            });
        };
        FilePondComponent.prototype.ngOnChanges = function (changes) {
            // no need to handle first change
            if (changes.firstChange) {
                return;
            }
            // no filepond instance available
            if (!this.pond) {
                return;
            }
            // use new options object as base ( or if not available, use current options )
            var options = changes.options
                ? changes.options.currentValue
                : this.options;
            // see if file list has changed
            if (changes.files &&
                JSON.stringify(changes.files.previousValue) !==
                    JSON.stringify(changes.files.currentValue)) {
                // file list has changed
                options.files = changes.files.currentValue;
            }
            // set new options
            this.pond.setOptions(options);
        };
        FilePondComponent.prototype.ngOnDestroy = function () {
            var _this = this;
            if (!this.pond) {
                return;
            }
            outputs.forEach(function (event) {
                _this.root.nativeElement.removeEventListener("FilePond:" + event.substr(2), _this.handleEvent);
            });
            this.pond.destroy();
        };
        return FilePondComponent;
    }());
    FilePondComponent.decorators = [
        { type: core.Component, args: [{
                    selector: "file-pond",
                    encapsulation: core.ViewEncapsulation.None,
                    template: "<div class=\"filepond--wrapper\">\n  <input type=\"file\"/>\n</div>",
                    styles: [""]
                },] }
    ];
    FilePondComponent.ctorParameters = function () { return [
        { type: core.ElementRef },
        { type: core.NgZone }
    ]; };
    FilePondComponent.propDecorators = {
        options: [{ type: core.Input }],
        files: [{ type: core.Input }],
        oninit: [{ type: core.Output }],
        onwarning: [{ type: core.Output }],
        onerror: [{ type: core.Output }],
        onactivatefile: [{ type: core.Output }],
        onaddfilestart: [{ type: core.Output }],
        onaddfileprogress: [{ type: core.Output }],
        onaddfile: [{ type: core.Output }],
        onprocessfilestart: [{ type: core.Output }],
        onprocessfileprogress: [{ type: core.Output }],
        onprocessfileabort: [{ type: core.Output }],
        onprocessfilerevert: [{ type: core.Output }],
        onprocessfile: [{ type: core.Output }],
        onprocessfiles: [{ type: core.Output }],
        onremovefile: [{ type: core.Output }],
        onpreparefile: [{ type: core.Output }],
        onupdatefiles: [{ type: core.Output }]
    };

    var FilePondModule = /** @class */ (function () {
        function FilePondModule() {
        }
        return FilePondModule;
    }());
    FilePondModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [
                        common.CommonModule
                    ],
                    declarations: [FilePondComponent],
                    exports: [
                        FilePondComponent
                    ]
                },] }
    ];

    /**
     * Generated bundle index. Do not edit.
     */

    Object.defineProperty(exports, 'registerPlugin', {
        enumerable: true,
        get: function () {
            return filepond.registerPlugin;
        }
    });
    exports.FilePondModule = FilePondModule;
    exports.ɵa = FilePondComponent;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ngx-filepond.umd.js.map
